VpnNoticePlatform class abstract
The interface implemented by all platform-specific implementations of
vpn_notice. Custom implementations (e.g. for testing) extend this.
- Inheritance
-
- Object
- PlatformInterface
- VpnNoticePlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isVpnActive(
) → Future< bool> - Performs a one-time check of whether a VPN connection is currently active.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
vpnStatusStream(
) → Stream< bool> - A broadcast stream of VPN connection status changes.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ VpnNoticePlatform
-
The active platform implementation. Defaults to MethodChannelVpnNotice.
getter/setter pair